#!/bin/bash

# this script updates all the bpq programs defined in the "programs" array
# if you define an email, and you have installed exim4, you will receive a
# notification when there are new updates
# inspired by: https://packet-radio.net/update-linbpq-with-up2bpq/
# Ricardo Oitavén, CT1EBQ @02/04/2020

# add the following line to the end of your crontab file, without the leading
# "#" character. Make "nano /etc/crontab" for this
# 0 2	* * *   pi-star /usr/local/bin/linbpq/update_bpq.sh
# change "pi-star" to your standard user, usually "pi"

# set variables
linbpq_local_path="/usr/local/bin/linbpq"
versions="$linbpq_local_path/versions"
#branch="Test"
branch="Beta"
linbpq_remote_path="https://www.cantab.net/users/john.wiseman/Downloads/${branch}"
declare -a programs=(
	'pilinbpq -s'
	'piQtSoundModem'
	'piQtTermTCP'
	'piQtBPQAPRS'
	'piARDOP_GUI'
	'piardopc'
	'piardopofdm'
)

cd $linbpq_local_path/

update () {
split=( $1 )
prg=${split[0]}
opt=${split[1]}

local=$(date -d "$( stat /usr/local/bin/linbpq/$prg | awk '/Modify/{gsub( /^[^:]+: +/,"",$0); print}' )" "+%s")
remote=$(date -d "$( curl -sI $linbpq_remote_path/$prg  | awk '/last-modified/{gsub( /^[^:]+: +/,"",$0); print}' )" "+%s")

# Compare the modified date`s and test if file exist on remote server
if [[ (($local -lt $remote) && (`wget -S --spider $linbpq_remote_path/$prg  2>&1 | grep 'HTTP/1.1 200 OK'`)) || ! -f $linbpq_local_path/$prg ]];
then
  # test if $versions directory exist
  if [ ! -d "$versions" ]; then
    mkdir $versions
    chown $user. $versions
    chmod 755 $versions
  fi
  # move and keep last version
  mv $linbpq_local_path/$prg $versions/${prg}_`date -d "@$local" +"%Y-%m-%d"`
  chmod -R 700 $versions
  # downloading new version
  wget -N $linbpq_remote_path/$prg -P $linbpq_local_path
  chown $user. $linbpq_local_path/$prg
  chmod 755 $linbpq_local_path/$prg
  # stop running if it is a service and wait for it to close
  process=`pgrep -x -a $prg`
  if [[ $opt == "-s" && ! "${process:-null}" = null ]]; then
    sudo pkill --signal 2 --exact $prg
    sleep 10
    echo "$prg has been updated! Wait for $prg to restart..."
  else
    echo "$prg has been updated!"
  fi
  body="${body}${prg}$nl"
  bmsg="${bmsg}${prg} "
else
  echo "No updates available for ${prg}"
fi
}

for i in "${programs[@]}"
do
  #echo "$i"
  update "$i"
done
